#define PERL_constant_NOTFOUND	1
#define PERL_constant_NOTDEF	2
#define PERL_constant_ISIV	3
#define PERL_constant_ISNO	4
#define PERL_constant_ISNV	5
#define PERL_constant_ISPV	6
#define PERL_constant_ISPVN	7
#define PERL_constant_ISSV	8
#define PERL_constant_ISUNDEF	9
#define PERL_constant_ISUV	10
#define PERL_constant_ISYES	11

#ifndef NVTYPE
typedef double NV; /* 5.6 and later define NVTYPE, and typedef NV to it.  */
#endif
#ifndef aTHX_
#define aTHX_ /* 5.6 or later define this for threading support.  */
#endif
#ifndef pTHX_
#define pTHX_ /* 5.6 or later define this for threading support.  */
#endif

/* This allows slightly more efficient code on !USE_ITHREADS: */
#ifdef USE_ITHREADS
#  define COP_FILE(c)	CopFILE(c)
#  define COP_FILE_F	"s"
#else
#  define COP_FILE(c)	CopFILESV(c)
#  define COP_FILE_F	SVf
#endif

static void
constant_add_symbol(pTHX_  HV *hash, const char *name, I32 namelen, SV *value) {
    HE *he = (HE*) hv_common_key_len(hash, name, namelen, HV_FETCH_LVALUE, NULL,
				     0);
    SV *sv;

    if (!he) {
        croak("Couldn't add key '%s' to %%POSIX::2008::",
		   name);
    }
    sv = HeVAL(he);
    if (SvOK(sv) || SvTYPE(sv) == SVt_PVGV) {
	/* Someone has been here before us - have to make a real sub.  */
	newCONSTSUB(hash, name, value);
    } else {
	SvUPGRADE(sv, SVt_RV);
	SvRV_set(sv, value);
	SvROK_on(sv);
	SvREADONLY_on(value);
    }
}



#ifndef SYMBIAN

/* Store a hash of all symbols missing from the package. To avoid trampling on
   the package namespace (uninvited) put each package's hash in our namespace.
   To avoid creating lots of typeblogs and symbol tables for sub-packages, put
   each package's hash into one hash in our namespace.  */

static HV *
get_missing_hash(pTHX) {
    HV *const parent
	= get_hv("ExtUtils::Constant::ProxySubs::Missing", GVf_MULTI);
    /* We could make a hash of hashes directly, but this would confuse anything
	at Perl space that looks at us, and as we're visible in Perl space,
	best to play nice. */
    SV *const *const ref
	= hv_fetch(parent, "POSIX::2008", 11, TRUE);
    HV *new_hv;

    if (!ref)
	return NULL;

    if (SvROK(*ref))
	return (HV*) SvRV(*ref);

    new_hv = newHV();
    SvUPGRADE(*ref, SVt_RV);
    SvRV_set(*ref, (SV *)new_hv);
    SvROK_on(*ref);
    return new_hv;
}

#endif

struct notfound_s {const char *name; I32 namelen;} ;

    static const struct notfound_s values_for_notfound[] =
      {
#ifndef AT_EACCESS
        { "AT_EACCESS", 10 },
#endif
#ifndef AT_EMPTY_PATH
        { "AT_EMPTY_PATH", 13 },
#endif
#ifndef AT_FDCWD
        { "AT_FDCWD", 8 },
#endif
#ifndef AT_NO_AUTOMOUNT
        { "AT_NO_AUTOMOUNT", 15 },
#endif
#ifndef AT_REMOVEDIR
        { "AT_REMOVEDIR", 12 },
#endif
#ifndef AT_RESOLVE_BENEATH
        { "AT_RESOLVE_BENEATH", 18 },
#endif
#ifndef AT_SYMLINK_FOLLOW
        { "AT_SYMLINK_FOLLOW", 17 },
#endif
#ifndef AT_SYMLINK_NOFOLLOW
        { "AT_SYMLINK_NOFOLLOW", 19 },
#endif
#ifndef BOOT_TIME
        { "BOOT_TIME", 9 },
#endif
#ifndef CLOCK_BOOTTIME
        { "CLOCK_BOOTTIME", 14 },
#endif
#ifndef CLOCK_HIGHRES
        { "CLOCK_HIGHRES", 13 },
#endif
#ifndef CLOCK_MONOTONIC
        { "CLOCK_MONOTONIC", 15 },
#endif
#ifndef CLOCK_MONOTONIC_COARSE
        { "CLOCK_MONOTONIC_COARSE", 22 },
#endif
#ifndef CLOCK_MONOTONIC_FAST
        { "CLOCK_MONOTONIC_FAST", 20 },
#endif
#ifndef CLOCK_MONOTONIC_PRECISE
        { "CLOCK_MONOTONIC_PRECISE", 23 },
#endif
#ifndef CLOCK_MONOTONIC_RAW
        { "CLOCK_MONOTONIC_RAW", 19 },
#endif
#ifndef CLOCK_PROCESS_CPUTIME_ID
        { "CLOCK_PROCESS_CPUTIME_ID", 24 },
#endif
#ifndef CLOCK_REALTIME
        { "CLOCK_REALTIME", 14 },
#endif
#ifndef CLOCK_REALTIME_COARSE
        { "CLOCK_REALTIME_COARSE", 21 },
#endif
#ifndef CLOCK_REALTIME_FAST
        { "CLOCK_REALTIME_FAST", 19 },
#endif
#ifndef CLOCK_REALTIME_PRECISE
        { "CLOCK_REALTIME_PRECISE", 22 },
#endif
#ifndef CLOCK_SOFTTIME
        { "CLOCK_SOFTTIME", 14 },
#endif
#ifndef CLOCK_THREAD_CPUTIME_ID
        { "CLOCK_THREAD_CPUTIME_ID", 23 },
#endif
#ifndef CLOCK_UPTIME
        { "CLOCK_UPTIME", 12 },
#endif
#ifndef CLOCK_UPTIME_FAST
        { "CLOCK_UPTIME_FAST", 17 },
#endif
#ifndef CLOCK_UPTIME_PRECISE
        { "CLOCK_UPTIME_PRECISE", 20 },
#endif
#ifndef DEAD_PROCESS
        { "DEAD_PROCESS", 12 },
#endif
#ifndef FASYNC
        { "FASYNC", 6 },
#endif
#ifndef F_DUPFD
        { "F_DUPFD", 7 },
#endif
#ifndef F_DUPFD_CLOEXEC
        { "F_DUPFD_CLOEXEC", 15 },
#endif
#ifndef F_GETFD
        { "F_GETFD", 7 },
#endif
#ifndef F_SETFD
        { "F_SETFD", 7 },
#endif
#ifndef F_GETFL
        { "F_GETFL", 7 },
#endif
#ifndef F_SETFL
        { "F_SETFL", 7 },
#endif
#ifndef F_GETLK
        { "F_GETLK", 7 },
#endif
#ifndef F_SETLK
        { "F_SETLK", 7 },
#endif
#ifndef F_SETLKW
        { "F_SETLKW", 8 },
#endif
#ifndef F_GETOWN
        { "F_GETOWN", 8 },
#endif
#ifndef F_SETOWN
        { "F_SETOWN", 8 },
#endif
#ifndef F_RDLCK
        { "F_RDLCK", 7 },
#endif
#ifndef F_UNLCK
        { "F_UNLCK", 7 },
#endif
#ifndef F_WRLCK
        { "F_WRLCK", 7 },
#endif
#ifndef FD_CLOEXEC
        { "FD_CLOEXEC", 10 },
#endif
#ifndef FE_TONEAREST
        { "FE_TONEAREST", 12 },
#endif
#ifndef FE_TOWARDZERO
        { "FE_TOWARDZERO", 13 },
#endif
#ifndef FE_UPWARD
        { "FE_UPWARD", 9 },
#endif
#ifndef FE_DOWNWARD
        { "FE_DOWNWARD", 11 },
#endif
#ifndef FE_DIVBYZERO
        { "FE_DIVBYZERO", 12 },
#endif
#ifndef FE_INEXACT
        { "FE_INEXACT", 10 },
#endif
#ifndef FE_INVALID
        { "FE_INVALID", 10 },
#endif
#ifndef FE_OVERFLOW
        { "FE_OVERFLOW", 11 },
#endif
#ifndef FE_UNDERFLOW
        { "FE_UNDERFLOW", 12 },
#endif
#ifndef FE_ALL_EXCEPT
        { "FE_ALL_EXCEPT", 13 },
#endif
#ifndef FNM_CASEFOLD
        { "FNM_CASEFOLD", 12 },
#endif
#ifndef FNM_FILE_NAME
        { "FNM_FILE_NAME", 13 },
#endif
#ifndef FNM_LEADING_DIR
        { "FNM_LEADING_DIR", 15 },
#endif
#ifndef FNM_NOESCAPE
        { "FNM_NOESCAPE", 12 },
#endif
#ifndef FNM_NOMATCH
        { "FNM_NOMATCH", 11 },
#endif
#ifndef FNM_PATHNAME
        { "FNM_PATHNAME", 12 },
#endif
#ifndef FNM_PERIOD
        { "FNM_PERIOD", 10 },
#endif
#ifndef FP_INFINITE
        { "FP_INFINITE", 11 },
#endif
#ifndef FP_NAN
        { "FP_NAN", 6 },
#endif
#ifndef FP_NORMAL
        { "FP_NORMAL", 9 },
#endif
#ifndef FP_SUBNORMAL
        { "FP_SUBNORMAL", 12 },
#endif
#ifndef FP_ZERO
        { "FP_ZERO", 7 },
#endif
#ifndef INIT_PROCESS
        { "INIT_PROCESS", 12 },
#endif
#ifndef ITIMER_PROF
        { "ITIMER_PROF", 11 },
#endif
#ifndef ITIMER_REAL
        { "ITIMER_REAL", 11 },
#endif
#ifndef ITIMER_VIRTUAL
        { "ITIMER_VIRTUAL", 14 },
#endif
#ifndef LOGIN_PROCESS
        { "LOGIN_PROCESS", 13 },
#endif
#ifndef NEW_TIME
        { "NEW_TIME", 8 },
#endif
#ifndef O_ACCMODE
        { "O_ACCMODE", 9 },
#endif
#ifndef O_ASYNC
        { "O_ASYNC", 7 },
#endif
#ifndef O_APPEND
        { "O_APPEND", 8 },
#endif
#ifndef O_CLOEXEC
        { "O_CLOEXEC", 9 },
#endif
#ifndef O_CREAT
        { "O_CREAT", 7 },
#endif
#ifndef O_DIRECT
        { "O_DIRECT", 8 },
#endif
#ifndef O_DIRECTORY
        { "O_DIRECTORY", 11 },
#endif
#ifndef O_DSYNC
        { "O_DSYNC", 7 },
#endif
#ifndef O_EMPTY_PATH
        { "O_EMPTY_PATH", 12 },
#endif
#ifndef O_EXEC
        { "O_EXEC", 6 },
#endif
#ifndef O_EXCL
        { "O_EXCL", 6 },
#endif
#ifndef O_EXLOCK
        { "O_EXLOCK", 8 },
#endif
#ifndef O_LARGEFILE
        { "O_LARGEFILE", 11 },
#endif
#ifndef O_NDELAY
        { "O_NDELAY", 8 },
#endif
#ifndef O_NOATIME
        { "O_NOATIME", 9 },
#endif
#ifndef O_NOCTTY
        { "O_NOCTTY", 8 },
#endif
#ifndef O_NOFOLLOW
        { "O_NOFOLLOW", 10 },
#endif
#ifndef O_NONBLOCK
        { "O_NONBLOCK", 10 },
#endif
#ifndef O_NOSIGPIPE
        { "O_NOSIGPIPE", 11 },
#endif
#ifndef O_PATH
        { "O_PATH", 6 },
#endif
#ifndef O_RDONLY
        { "O_RDONLY", 8 },
#endif
#ifndef O_RDWR
        { "O_RDWR", 6 },
#endif
#ifndef O_RESOLVE_BENEATH
        { "O_RESOLVE_BENEATH", 17 },
#endif
#ifndef O_REGULAR
        { "O_REGULAR", 9 },
#endif
#ifndef O_RSYNC
        { "O_RSYNC", 7 },
#endif
#ifndef O_SEARCH
        { "O_SEARCH", 8 },
#endif
#ifndef O_SHLOCK
        { "O_SHLOCK", 8 },
#endif
#ifndef O_SYNC
        { "O_SYNC", 6 },
#endif
#ifndef O_TMPFILE
        { "O_TMPFILE", 9 },
#endif
#ifndef O_TRUNC
        { "O_TRUNC", 7 },
#endif
#ifndef O_TTY_INIT
        { "O_TTY_INIT", 10 },
#endif
#ifndef O_WRONLY
        { "O_WRONLY", 8 },
#endif
#ifndef OLD_TIME
        { "OLD_TIME", 8 },
#endif
#ifndef POSIX_FADV_NORMAL
        { "POSIX_FADV_NORMAL", 17 },
#endif
#ifndef POSIX_FADV_SEQUENTIAL
        { "POSIX_FADV_SEQUENTIAL", 21 },
#endif
#ifndef POSIX_FADV_RANDOM
        { "POSIX_FADV_RANDOM", 17 },
#endif
#ifndef POSIX_FADV_NOREUSE
        { "POSIX_FADV_NOREUSE", 18 },
#endif
#ifndef POSIX_FADV_WILLNEED
        { "POSIX_FADV_WILLNEED", 19 },
#endif
#ifndef POSIX_FADV_DONTNEED
        { "POSIX_FADV_DONTNEED", 19 },
#endif
#ifndef PRIO_PROCESS
        { "PRIO_PROCESS", 12 },
#endif
#ifndef PRIO_PGRP
        { "PRIO_PGRP", 9 },
#endif
#ifndef PRIO_USER
        { "PRIO_USER", 9 },
#endif
#ifndef RENAME_EXCHANGE
        { "RENAME_EXCHANGE", 15 },
#endif
#ifndef RENAME_NOREPLACE
        { "RENAME_NOREPLACE", 16 },
#endif
#ifndef RENAME_WHITEOUT
        { "RENAME_WHITEOUT", 15 },
#endif
#ifndef RESOLVE_BENEATH
        { "RESOLVE_BENEATH", 15 },
#endif
#ifndef RESOLVE_IN_ROOT
        { "RESOLVE_IN_ROOT", 15 },
#endif
#ifndef RESOLVE_NO_MAGICLINKS
        { "RESOLVE_NO_MAGICLINKS", 21 },
#endif
#ifndef RESOLVE_NO_SYMLINKS
        { "RESOLVE_NO_SYMLINKS", 19 },
#endif
#ifndef RESOLVE_NO_XDEV
        { "RESOLVE_NO_XDEV", 15 },
#endif
#ifndef RESOLVE_CACHED
        { "RESOLVE_CACHED", 14 },
#endif
#ifndef RTLD_DEEPBIND
        { "RTLD_DEEPBIND", 13 },
#endif
#ifndef RTLD_GLOBAL
        { "RTLD_GLOBAL", 11 },
#endif
#ifndef RTLD_LAZY
        { "RTLD_LAZY", 9 },
#endif
#ifndef RTLD_LOCAL
        { "RTLD_LOCAL", 10 },
#endif
#ifndef RTLD_MEMBER
        { "RTLD_MEMBER", 11 },
#endif
#ifndef RTLD_NOAUTODEFER
        { "RTLD_NOAUTODEFER", 16 },
#endif
#ifndef RTLD_NODELETE
        { "RTLD_NODELETE", 13 },
#endif
#ifndef RTLD_NOLOAD
        { "RTLD_NOLOAD", 11 },
#endif
#ifndef RTLD_NOW
        { "RTLD_NOW", 8 },
#endif
#ifndef RUN_LVL
        { "RUN_LVL", 7 },
#endif
#ifndef RWF_DSYNC
        { "RWF_DSYNC", 9 },
#endif
#ifndef RWF_HIPRI
        { "RWF_HIPRI", 9 },
#endif
#ifndef RWF_SYNC
        { "RWF_SYNC", 8 },
#endif
#ifndef RWF_NOWAIT
        { "RWF_NOWAIT", 10 },
#endif
#ifndef RWF_APPEND
        { "RWF_APPEND", 10 },
#endif
#ifndef S_IFMT
        { "S_IFMT", 6 },
#endif
#ifndef S_IFBLK
        { "S_IFBLK", 7 },
#endif
#ifndef S_IFCHR
        { "S_IFCHR", 7 },
#endif
#ifndef S_IFIFO
        { "S_IFIFO", 7 },
#endif
#ifndef S_IFREG
        { "S_IFREG", 7 },
#endif
#ifndef S_IFDIR
        { "S_IFDIR", 7 },
#endif
#ifndef S_IFLNK
        { "S_IFLNK", 7 },
#endif
#ifndef S_IFSOCK
        { "S_IFSOCK", 8 },
#endif
#ifndef S_ISUID
        { "S_ISUID", 7 },
#endif
#ifndef S_ISGID
        { "S_ISGID", 7 },
#endif
#ifndef S_IRWXU
        { "S_IRWXU", 7 },
#endif
#ifndef S_IRUSR
        { "S_IRUSR", 7 },
#endif
#ifndef S_IWUSR
        { "S_IWUSR", 7 },
#endif
#ifndef S_IXUSR
        { "S_IXUSR", 7 },
#endif
#ifndef S_IRWXG
        { "S_IRWXG", 7 },
#endif
#ifndef S_IRGRP
        { "S_IRGRP", 7 },
#endif
#ifndef S_IWGRP
        { "S_IWGRP", 7 },
#endif
#ifndef S_IXGRP
        { "S_IXGRP", 7 },
#endif
#ifndef S_IRWXO
        { "S_IRWXO", 7 },
#endif
#ifndef S_IROTH
        { "S_IROTH", 7 },
#endif
#ifndef S_IWOTH
        { "S_IWOTH", 7 },
#endif
#ifndef S_IXOTH
        { "S_IXOTH", 7 },
#endif
#ifndef S_ISVTX
        { "S_ISVTX", 7 },
#endif
#ifndef SEEK_SET
        { "SEEK_SET", 8 },
#endif
#ifndef SEEK_CUR
        { "SEEK_CUR", 8 },
#endif
#ifndef SEEK_END
        { "SEEK_END", 8 },
#endif
#ifndef SEEK_DATA
        { "SEEK_DATA", 9 },
#endif
#ifndef SEEK_HOLE
        { "SEEK_HOLE", 9 },
#endif
#ifndef TIMER_ABSTIME
        { "TIMER_ABSTIME", 13 },
#endif
#ifndef USER_PROCESS
        { "USER_PROCESS", 12 },
#endif
#ifndef UTIME_NOW
        { "UTIME_NOW", 9 },
#endif
#ifndef UTIME_OMIT
        { "UTIME_OMIT", 10 },
#endif
#ifndef F_OK
        { "F_OK", 4 },
#endif
#ifndef R_OK
        { "R_OK", 4 },
#endif
#ifndef W_OK
        { "W_OK", 4 },
#endif
#ifndef X_OK
        { "X_OK", 4 },
#endif
#ifndef _CS_GNU_LIBC_VERSION
        { "_CS_GNU_LIBC_VERSION", 20 },
#endif
#ifndef _CS_GNU_LIBPTHREAD_VERSION
        { "_CS_GNU_LIBPTHREAD_VERSION", 26 },
#endif
#ifndef _CS_LFS64_CFLAGS
        { "_CS_LFS64_CFLAGS", 16 },
#endif
#ifndef _CS_LFS64_LDFLAGS
        { "_CS_LFS64_LDFLAGS", 17 },
#endif
#ifndef _CS_LFS64_LIBS
        { "_CS_LFS64_LIBS", 14 },
#endif
#ifndef _CS_LFS64_LINTFLAGS
        { "_CS_LFS64_LINTFLAGS", 19 },
#endif
#ifndef _CS_LFS_CFLAGS
        { "_CS_LFS_CFLAGS", 14 },
#endif
#ifndef _CS_LFS_LDFLAGS
        { "_CS_LFS_LDFLAGS", 15 },
#endif
#ifndef _CS_LFS_LIBS
        { "_CS_LFS_LIBS", 12 },
#endif
#ifndef _CS_LFS_LINTFLAGS
        { "_CS_LFS_LINTFLAGS", 17 },
#endif
#ifndef _CS_PATH
        { "_CS_PATH", 8 },
#endif
#ifndef _CS_POSIX_V5_WIDTH_RESTRICTED_ENVS
        { "_CS_POSIX_V5_WIDTH_RESTRICTED_ENVS", 34 },
#endif
#ifndef _CS_POSIX_V6_ILP32_OFF32_CFLAGS
        { "_CS_POSIX_V6_ILP32_OFF32_CFLAGS", 31 },
#endif
#ifndef _CS_POSIX_V6_ILP32_OFF32_LDFLAGS
        { "_CS_POSIX_V6_ILP32_OFF32_LDFLAGS", 32 },
#endif
#ifndef _CS_POSIX_V6_ILP32_OFF32_LIBS
        { "_CS_POSIX_V6_ILP32_OFF32_LIBS", 29 },
#endif
#ifndef _CS_POSIX_V6_ILP32_OFF32_LINTFLAGS
        { "_CS_POSIX_V6_ILP32_OFF32_LINTFLAGS", 34 },
#endif
#ifndef _CS_POSIX_V6_ILP32_OFFBIG_CFLAGS
        { "_CS_POSIX_V6_ILP32_OFFBIG_CFLAGS", 32 },
#endif
#ifndef _CS_POSIX_V6_ILP32_OFFBIG_LDFLAGS
        { "_CS_POSIX_V6_ILP32_OFFBIG_LDFLAGS", 33 },
#endif
#ifndef _CS_POSIX_V6_ILP32_OFFBIG_LIBS
        { "_CS_POSIX_V6_ILP32_OFFBIG_LIBS", 30 },
#endif
#ifndef _CS_POSIX_V6_ILP32_OFFBIG_LINTFLAGS
        { "_CS_POSIX_V6_ILP32_OFFBIG_LINTFLAGS", 35 },
#endif
#ifndef _CS_POSIX_V6_LP64_OFF64_CFLAGS
        { "_CS_POSIX_V6_LP64_OFF64_CFLAGS", 30 },
#endif
#ifndef _CS_POSIX_V6_LP64_OFF64_LDFLAGS
        { "_CS_POSIX_V6_LP64_OFF64_LDFLAGS", 31 },
#endif
#ifndef _CS_POSIX_V6_LP64_OFF64_LIBS
        { "_CS_POSIX_V6_LP64_OFF64_LIBS", 28 },
#endif
#ifndef _CS_POSIX_V6_LP64_OFF64_LINTFLAGS
        { "_CS_POSIX_V6_LP64_OFF64_LINTFLAGS", 33 },
#endif
#ifndef _CS_POSIX_V6_LPBIG_OFFBIG_CFLAGS
        { "_CS_POSIX_V6_LPBIG_OFFBIG_CFLAGS", 32 },
#endif
#ifndef _CS_POSIX_V6_LPBIG_OFFBIG_LDFLAGS
        { "_CS_POSIX_V6_LPBIG_OFFBIG_LDFLAGS", 33 },
#endif
#ifndef _CS_POSIX_V6_LPBIG_OFFBIG_LIBS
        { "_CS_POSIX_V6_LPBIG_OFFBIG_LIBS", 30 },
#endif
#ifndef _CS_POSIX_V6_LPBIG_OFFBIG_LINTFLAGS
        { "_CS_POSIX_V6_LPBIG_OFFBIG_LINTFLAGS", 35 },
#endif
#ifndef _CS_POSIX_V6_WIDTH_RESTRICTED_ENVS
        { "_CS_POSIX_V6_WIDTH_RESTRICTED_ENVS", 34 },
#endif
#ifndef _CS_POSIX_V7_ILP32_OFF32_CFLAGS
        { "_CS_POSIX_V7_ILP32_OFF32_CFLAGS", 31 },
#endif
#ifndef _CS_POSIX_V7_ILP32_OFF32_LDFLAGS
        { "_CS_POSIX_V7_ILP32_OFF32_LDFLAGS", 32 },
#endif
#ifndef _CS_POSIX_V7_ILP32_OFF32_LIBS
        { "_CS_POSIX_V7_ILP32_OFF32_LIBS", 29 },
#endif
#ifndef _CS_POSIX_V7_ILP32_OFF32_LINTFLAGS
        { "_CS_POSIX_V7_ILP32_OFF32_LINTFLAGS", 34 },
#endif
#ifndef _CS_POSIX_V7_ILP32_OFFBIG_CFLAGS
        { "_CS_POSIX_V7_ILP32_OFFBIG_CFLAGS", 32 },
#endif
#ifndef _CS_POSIX_V7_ILP32_OFFBIG_LDFLAGS
        { "_CS_POSIX_V7_ILP32_OFFBIG_LDFLAGS", 33 },
#endif
#ifndef _CS_POSIX_V7_ILP32_OFFBIG_LIBS
        { "_CS_POSIX_V7_ILP32_OFFBIG_LIBS", 30 },
#endif
#ifndef _CS_POSIX_V7_ILP32_OFFBIG_LINTFLAGS
        { "_CS_POSIX_V7_ILP32_OFFBIG_LINTFLAGS", 35 },
#endif
#ifndef _CS_POSIX_V7_LP64_OFF64_CFLAGS
        { "_CS_POSIX_V7_LP64_OFF64_CFLAGS", 30 },
#endif
#ifndef _CS_POSIX_V7_LP64_OFF64_LDFLAGS
        { "_CS_POSIX_V7_LP64_OFF64_LDFLAGS", 31 },
#endif
#ifndef _CS_POSIX_V7_LP64_OFF64_LIBS
        { "_CS_POSIX_V7_LP64_OFF64_LIBS", 28 },
#endif
#ifndef _CS_POSIX_V7_LP64_OFF64_LINTFLAGS
        { "_CS_POSIX_V7_LP64_OFF64_LINTFLAGS", 33 },
#endif
#ifndef _CS_POSIX_V7_LPBIG_OFFBIG_CFLAGS
        { "_CS_POSIX_V7_LPBIG_OFFBIG_CFLAGS", 32 },
#endif
#ifndef _CS_POSIX_V7_LPBIG_OFFBIG_LDFLAGS
        { "_CS_POSIX_V7_LPBIG_OFFBIG_LDFLAGS", 33 },
#endif
#ifndef _CS_POSIX_V7_LPBIG_OFFBIG_LIBS
        { "_CS_POSIX_V7_LPBIG_OFFBIG_LIBS", 30 },
#endif
#ifndef _CS_POSIX_V7_LPBIG_OFFBIG_LINTFLAGS
        { "_CS_POSIX_V7_LPBIG_OFFBIG_LINTFLAGS", 35 },
#endif
#ifndef _CS_POSIX_V7_WIDTH_RESTRICTED_ENVS
        { "_CS_POSIX_V7_WIDTH_RESTRICTED_ENVS", 34 },
#endif
#ifndef _CS_V5_WIDTH_RESTRICTED_ENVS
        { "_CS_V5_WIDTH_RESTRICTED_ENVS", 28 },
#endif
#ifndef _CS_V6_ENV
        { "_CS_V6_ENV", 10 },
#endif
#ifndef _CS_V6_WIDTH_RESTRICTED_ENVS
        { "_CS_V6_WIDTH_RESTRICTED_ENVS", 28 },
#endif
#ifndef _CS_V7_ENV
        { "_CS_V7_ENV", 10 },
#endif
#ifndef _CS_V7_WIDTH_RESTRICTED_ENVS
        { "_CS_V7_WIDTH_RESTRICTED_ENVS", 28 },
#endif
#ifndef _CS_XBS5_ILP32_OFF32_CFLAGS
        { "_CS_XBS5_ILP32_OFF32_CFLAGS", 27 },
#endif
#ifndef _CS_XBS5_ILP32_OFF32_LDFLAGS
        { "_CS_XBS5_ILP32_OFF32_LDFLAGS", 28 },
#endif
#ifndef _CS_XBS5_ILP32_OFF32_LIBS
        { "_CS_XBS5_ILP32_OFF32_LIBS", 25 },
#endif
#ifndef _CS_XBS5_ILP32_OFF32_LINTFLAGS
        { "_CS_XBS5_ILP32_OFF32_LINTFLAGS", 30 },
#endif
#ifndef _CS_XBS5_ILP32_OFFBIG_CFLAGS
        { "_CS_XBS5_ILP32_OFFBIG_CFLAGS", 28 },
#endif
#ifndef _CS_XBS5_ILP32_OFFBIG_LDFLAGS
        { "_CS_XBS5_ILP32_OFFBIG_LDFLAGS", 29 },
#endif
#ifndef _CS_XBS5_ILP32_OFFBIG_LIBS
        { "_CS_XBS5_ILP32_OFFBIG_LIBS", 26 },
#endif
#ifndef _CS_XBS5_ILP32_OFFBIG_LINTFLAGS
        { "_CS_XBS5_ILP32_OFFBIG_LINTFLAGS", 31 },
#endif
#ifndef _CS_XBS5_LP64_OFF64_CFLAGS
        { "_CS_XBS5_LP64_OFF64_CFLAGS", 26 },
#endif
#ifndef _CS_XBS5_LP64_OFF64_LDFLAGS
        { "_CS_XBS5_LP64_OFF64_LDFLAGS", 27 },
#endif
#ifndef _CS_XBS5_LP64_OFF64_LIBS
        { "_CS_XBS5_LP64_OFF64_LIBS", 24 },
#endif
#ifndef _CS_XBS5_LP64_OFF64_LINTFLAGS
        { "_CS_XBS5_LP64_OFF64_LINTFLAGS", 29 },
#endif
#ifndef _CS_XBS5_LPBIG_OFFBIG_CFLAGS
        { "_CS_XBS5_LPBIG_OFFBIG_CFLAGS", 28 },
#endif
#ifndef _CS_XBS5_LPBIG_OFFBIG_LDFLAGS
        { "_CS_XBS5_LPBIG_OFFBIG_LDFLAGS", 29 },
#endif
#ifndef _CS_XBS5_LPBIG_OFFBIG_LIBS
        { "_CS_XBS5_LPBIG_OFFBIG_LIBS", 26 },
#endif
#ifndef _CS_XBS5_LPBIG_OFFBIG_LINTFLAGS
        { "_CS_XBS5_LPBIG_OFFBIG_LINTFLAGS", 31 },
#endif
#ifndef _PC_2_SYMLINKS
        { "_PC_2_SYMLINKS", 14 },
#endif
#ifndef _PC_ALLOC_SIZE_MIN
        { "_PC_ALLOC_SIZE_MIN", 18 },
#endif
#ifndef _PC_ASYNC_IO
        { "_PC_ASYNC_IO", 12 },
#endif
#ifndef _PC_CHOWN_RESTRICTED
        { "_PC_CHOWN_RESTRICTED", 20 },
#endif
#ifndef _PC_FILESIZEBITS
        { "_PC_FILESIZEBITS", 16 },
#endif
#ifndef _PC_LINK_MAX
        { "_PC_LINK_MAX", 12 },
#endif
#ifndef _PC_MAX_CANON
        { "_PC_MAX_CANON", 13 },
#endif
#ifndef _PC_MAX_INPUT
        { "_PC_MAX_INPUT", 13 },
#endif
#ifndef _PC_NAME_MAX
        { "_PC_NAME_MAX", 12 },
#endif
#ifndef _PC_NO_TRUNC
        { "_PC_NO_TRUNC", 12 },
#endif
#ifndef _PC_PATH_MAX
        { "_PC_PATH_MAX", 12 },
#endif
#ifndef _PC_PIPE_BUF
        { "_PC_PIPE_BUF", 12 },
#endif
#ifndef _PC_PRIO_IO
        { "_PC_PRIO_IO", 11 },
#endif
#ifndef _PC_REC_INCR_XFER_SIZE
        { "_PC_REC_INCR_XFER_SIZE", 22 },
#endif
#ifndef _PC_REC_MAX_XFER_SIZE
        { "_PC_REC_MAX_XFER_SIZE", 21 },
#endif
#ifndef _PC_REC_MIN_XFER_SIZE
        { "_PC_REC_MIN_XFER_SIZE", 21 },
#endif
#ifndef _PC_REC_XFER_ALIGN
        { "_PC_REC_XFER_ALIGN", 18 },
#endif
#ifndef _PC_SOCK_MAXBUF
        { "_PC_SOCK_MAXBUF", 15 },
#endif
#ifndef _PC_SYMLINK_MAX
        { "_PC_SYMLINK_MAX", 15 },
#endif
#ifndef _PC_SYNC_IO
        { "_PC_SYNC_IO", 11 },
#endif
#ifndef _PC_VDISABLE
        { "_PC_VDISABLE", 12 },
#endif
#ifndef _SC_2_CHAR_TERM
        { "_SC_2_CHAR_TERM", 15 },
#endif
#ifndef _SC_2_C_BIND
        { "_SC_2_C_BIND", 12 },
#endif
#ifndef _SC_2_C_DEV
        { "_SC_2_C_DEV", 11 },
#endif
#ifndef _SC_2_C_VERSION
        { "_SC_2_C_VERSION", 15 },
#endif
#ifndef _SC_2_FORT_DEV
        { "_SC_2_FORT_DEV", 14 },
#endif
#ifndef _SC_2_FORT_RUN
        { "_SC_2_FORT_RUN", 14 },
#endif
#ifndef _SC_2_LOCALEDEF
        { "_SC_2_LOCALEDEF", 15 },
#endif
#ifndef _SC_2_PBS
        { "_SC_2_PBS", 9 },
#endif
#ifndef _SC_2_PBS_ACCOUNTING
        { "_SC_2_PBS_ACCOUNTING", 20 },
#endif
#ifndef _SC_2_PBS_CHECKPOINT
        { "_SC_2_PBS_CHECKPOINT", 20 },
#endif
#ifndef _SC_2_PBS_LOCATE
        { "_SC_2_PBS_LOCATE", 16 },
#endif
#ifndef _SC_2_PBS_MESSAGE
        { "_SC_2_PBS_MESSAGE", 17 },
#endif
#ifndef _SC_2_PBS_TRACK
        { "_SC_2_PBS_TRACK", 15 },
#endif
#ifndef _SC_2_SW_DEV
        { "_SC_2_SW_DEV", 12 },
#endif
#ifndef _SC_2_UPE
        { "_SC_2_UPE", 9 },
#endif
#ifndef _SC_2_VERSION
        { "_SC_2_VERSION", 13 },
#endif
#ifndef _SC_ADVISORY_INFO
        { "_SC_ADVISORY_INFO", 17 },
#endif
#ifndef _SC_AIO_LISTIO_MAX
        { "_SC_AIO_LISTIO_MAX", 18 },
#endif
#ifndef _SC_AIO_MAX
        { "_SC_AIO_MAX", 11 },
#endif
#ifndef _SC_AIO_PRIO_DELTA_MAX
        { "_SC_AIO_PRIO_DELTA_MAX", 22 },
#endif
#ifndef _SC_ARG_MAX
        { "_SC_ARG_MAX", 11 },
#endif
#ifndef _SC_ASYNCHRONOUS_IO
        { "_SC_ASYNCHRONOUS_IO", 19 },
#endif
#ifndef _SC_ATEXIT_MAX
        { "_SC_ATEXIT_MAX", 14 },
#endif
#ifndef _SC_AVPHYS_PAGES
        { "_SC_AVPHYS_PAGES", 16 },
#endif
#ifndef _SC_BARRIERS
        { "_SC_BARRIERS", 12 },
#endif
#ifndef _SC_BASE
        { "_SC_BASE", 8 },
#endif
#ifndef _SC_BC_BASE_MAX
        { "_SC_BC_BASE_MAX", 15 },
#endif
#ifndef _SC_BC_DIM_MAX
        { "_SC_BC_DIM_MAX", 14 },
#endif
#ifndef _SC_BC_SCALE_MAX
        { "_SC_BC_SCALE_MAX", 16 },
#endif
#ifndef _SC_BC_STRING_MAX
        { "_SC_BC_STRING_MAX", 17 },
#endif
#ifndef _SC_CHARCLASS_NAME_MAX
        { "_SC_CHARCLASS_NAME_MAX", 22 },
#endif
#ifndef _SC_CHAR_BIT
        { "_SC_CHAR_BIT", 12 },
#endif
#ifndef _SC_CHAR_MAX
        { "_SC_CHAR_MAX", 12 },
#endif
#ifndef _SC_CHAR_MIN
        { "_SC_CHAR_MIN", 12 },
#endif
#ifndef _SC_CHILD_MAX
        { "_SC_CHILD_MAX", 13 },
#endif
#ifndef _SC_CLK_TCK
        { "_SC_CLK_TCK", 11 },
#endif
#ifndef _SC_CLOCK_SELECTION
        { "_SC_CLOCK_SELECTION", 19 },
#endif
#ifndef _SC_COLL_WEIGHTS_MAX
        { "_SC_COLL_WEIGHTS_MAX", 20 },
#endif
#ifndef _SC_CPUTIME
        { "_SC_CPUTIME", 11 },
#endif
#ifndef _SC_C_LANG_SUPPORT
        { "_SC_C_LANG_SUPPORT", 18 },
#endif
#ifndef _SC_C_LANG_SUPPORT_R
        { "_SC_C_LANG_SUPPORT_R", 20 },
#endif
#ifndef _SC_DELAYTIMER_MAX
        { "_SC_DELAYTIMER_MAX", 18 },
#endif
#ifndef _SC_DEVICE_IO
        { "_SC_DEVICE_IO", 13 },
#endif
#ifndef _SC_DEVICE_SPECIFIC
        { "_SC_DEVICE_SPECIFIC", 19 },
#endif
#ifndef _SC_DEVICE_SPECIFIC_R
        { "_SC_DEVICE_SPECIFIC_R", 21 },
#endif
#ifndef _SC_EQUIV_CLASS_MAX
        { "_SC_EQUIV_CLASS_MAX", 19 },
#endif
#ifndef _SC_EXPR_NEST_MAX
        { "_SC_EXPR_NEST_MAX", 17 },
#endif
#ifndef _SC_FD_MGMT
        { "_SC_FD_MGMT", 11 },
#endif
#ifndef _SC_FIFO
        { "_SC_FIFO", 8 },
#endif
#ifndef _SC_FILE_ATTRIBUTES
        { "_SC_FILE_ATTRIBUTES", 19 },
#endif
#ifndef _SC_FILE_LOCKING
        { "_SC_FILE_LOCKING", 16 },
#endif
#ifndef _SC_FILE_SYSTEM
        { "_SC_FILE_SYSTEM", 15 },
#endif
#ifndef _SC_FSYNC
        { "_SC_FSYNC", 9 },
#endif
#ifndef _SC_GETGR_R_SIZE_MAX
        { "_SC_GETGR_R_SIZE_MAX", 20 },
#endif
#ifndef _SC_GETPW_R_SIZE_MAX
        { "_SC_GETPW_R_SIZE_MAX", 20 },
#endif
#ifndef _SC_HOST_NAME_MAX
        { "_SC_HOST_NAME_MAX", 17 },
#endif
#ifndef _SC_INT_MAX
        { "_SC_INT_MAX", 11 },
#endif
#ifndef _SC_INT_MIN
        { "_SC_INT_MIN", 11 },
#endif
#ifndef _SC_IOV_MAX
        { "_SC_IOV_MAX", 11 },
#endif
#ifndef _SC_IPV6
        { "_SC_IPV6", 8 },
#endif
#ifndef _SC_JOB_CONTROL
        { "_SC_JOB_CONTROL", 15 },
#endif
#ifndef _SC_LEVEL1_DCACHE_ASSOC
        { "_SC_LEVEL1_DCACHE_ASSOC", 23 },
#endif
#ifndef _SC_LEVEL1_DCACHE_LINESIZE
        { "_SC_LEVEL1_DCACHE_LINESIZE", 26 },
#endif
#ifndef _SC_LEVEL1_DCACHE_SIZE
        { "_SC_LEVEL1_DCACHE_SIZE", 22 },
#endif
#ifndef _SC_LEVEL1_ICACHE_ASSOC
        { "_SC_LEVEL1_ICACHE_ASSOC", 23 },
#endif
#ifndef _SC_LEVEL1_ICACHE_LINESIZE
        { "_SC_LEVEL1_ICACHE_LINESIZE", 26 },
#endif
#ifndef _SC_LEVEL1_ICACHE_SIZE
        { "_SC_LEVEL1_ICACHE_SIZE", 22 },
#endif
#ifndef _SC_LEVEL2_CACHE_ASSOC
        { "_SC_LEVEL2_CACHE_ASSOC", 22 },
#endif
#ifndef _SC_LEVEL2_CACHE_LINESIZE
        { "_SC_LEVEL2_CACHE_LINESIZE", 25 },
#endif
#ifndef _SC_LEVEL2_CACHE_SIZE
        { "_SC_LEVEL2_CACHE_SIZE", 21 },
#endif
#ifndef _SC_LEVEL3_CACHE_ASSOC
        { "_SC_LEVEL3_CACHE_ASSOC", 22 },
#endif
#ifndef _SC_LEVEL3_CACHE_LINESIZE
        { "_SC_LEVEL3_CACHE_LINESIZE", 25 },
#endif
#ifndef _SC_LEVEL3_CACHE_SIZE
        { "_SC_LEVEL3_CACHE_SIZE", 21 },
#endif
#ifndef _SC_LEVEL4_CACHE_ASSOC
        { "_SC_LEVEL4_CACHE_ASSOC", 22 },
#endif
#ifndef _SC_LEVEL4_CACHE_LINESIZE
        { "_SC_LEVEL4_CACHE_LINESIZE", 25 },
#endif
#ifndef _SC_LEVEL4_CACHE_SIZE
        { "_SC_LEVEL4_CACHE_SIZE", 21 },
#endif
#ifndef _SC_LINE_MAX
        { "_SC_LINE_MAX", 12 },
#endif
#ifndef _SC_LOGIN_NAME_MAX
        { "_SC_LOGIN_NAME_MAX", 18 },
#endif
#ifndef _SC_LONG_BIT
        { "_SC_LONG_BIT", 12 },
#endif
#ifndef _SC_MAPPED_FILES
        { "_SC_MAPPED_FILES", 16 },
#endif
#ifndef _SC_MB_LEN_MAX
        { "_SC_MB_LEN_MAX", 14 },
#endif
#ifndef _SC_MEMLOCK
        { "_SC_MEMLOCK", 11 },
#endif
#ifndef _SC_MEMLOCK_RANGE
        { "_SC_MEMLOCK_RANGE", 17 },
#endif
#ifndef _SC_MEMORY_PROTECTION
        { "_SC_MEMORY_PROTECTION", 21 },
#endif
#ifndef _SC_MESSAGE_PASSING
        { "_SC_MESSAGE_PASSING", 19 },
#endif
#ifndef _SC_MINSIGSTKSZ
        { "_SC_MINSIGSTKSZ", 15 },
#endif
#ifndef _SC_MONOTONIC_CLOCK
        { "_SC_MONOTONIC_CLOCK", 19 },
#endif
#ifndef _SC_MQ_OPEN_MAX
        { "_SC_MQ_OPEN_MAX", 15 },
#endif
#ifndef _SC_MQ_PRIO_MAX
        { "_SC_MQ_PRIO_MAX", 15 },
#endif
#ifndef _SC_MULTI_PROCESS
        { "_SC_MULTI_PROCESS", 17 },
#endif
#ifndef _SC_NETWORKING
        { "_SC_NETWORKING", 14 },
#endif
#ifndef _SC_NGROUPS_MAX
        { "_SC_NGROUPS_MAX", 15 },
#endif
#ifndef _SC_NL_ARGMAX
        { "_SC_NL_ARGMAX", 13 },
#endif
#ifndef _SC_NL_LANGMAX
        { "_SC_NL_LANGMAX", 14 },
#endif
#ifndef _SC_NL_MSGMAX
        { "_SC_NL_MSGMAX", 13 },
#endif
#ifndef _SC_NL_NMAX
        { "_SC_NL_NMAX", 11 },
#endif
#ifndef _SC_NL_SETMAX
        { "_SC_NL_SETMAX", 13 },
#endif
#ifndef _SC_NL_TEXTMAX
        { "_SC_NL_TEXTMAX", 14 },
#endif
#ifndef _SC_NPROCESSORS_CONF
        { "_SC_NPROCESSORS_CONF", 20 },
#endif
#ifndef _SC_NPROCESSORS_ONLN
        { "_SC_NPROCESSORS_ONLN", 20 },
#endif
#ifndef _SC_NZERO
        { "_SC_NZERO", 9 },
#endif
#ifndef _SC_OPEN_MAX
        { "_SC_OPEN_MAX", 12 },
#endif
#ifndef _SC_PAGESIZE
        { "_SC_PAGESIZE", 12 },
#endif
#ifndef _SC_PAGE_SIZE
        { "_SC_PAGE_SIZE", 13 },
#endif
#ifndef _SC_PASS_MAX
        { "_SC_PASS_MAX", 12 },
#endif
#ifndef _SC_PHYS_PAGES
        { "_SC_PHYS_PAGES", 14 },
#endif
#ifndef _SC_PII
        { "_SC_PII", 7 },
#endif
#ifndef _SC_PII_INTERNET
        { "_SC_PII_INTERNET", 16 },
#endif
#ifndef _SC_PII_INTERNET_DGRAM
        { "_SC_PII_INTERNET_DGRAM", 22 },
#endif
#ifndef _SC_PII_INTERNET_STREAM
        { "_SC_PII_INTERNET_STREAM", 23 },
#endif
#ifndef _SC_PII_OSI
        { "_SC_PII_OSI", 11 },
#endif
#ifndef _SC_PII_OSI_CLTS
        { "_SC_PII_OSI_CLTS", 16 },
#endif
#ifndef _SC_PII_OSI_COTS
        { "_SC_PII_OSI_COTS", 16 },
#endif
#ifndef _SC_PII_OSI_M
        { "_SC_PII_OSI_M", 13 },
#endif
#ifndef _SC_PII_SOCKET
        { "_SC_PII_SOCKET", 14 },
#endif
#ifndef _SC_PII_XTI
        { "_SC_PII_XTI", 11 },
#endif
#ifndef _SC_PIPE
        { "_SC_PIPE", 8 },
#endif
#ifndef _SC_POLL
        { "_SC_POLL", 8 },
#endif
#ifndef _SC_PRIORITIZED_IO
        { "_SC_PRIORITIZED_IO", 18 },
#endif
#ifndef _SC_PRIORITY_SCHEDULING
        { "_SC_PRIORITY_SCHEDULING", 23 },
#endif
#ifndef _SC_RAW_SOCKETS
        { "_SC_RAW_SOCKETS", 15 },
#endif
#ifndef _SC_READER_WRITER_LOCKS
        { "_SC_READER_WRITER_LOCKS", 23 },
#endif
#ifndef _SC_REALTIME_SIGNALS
        { "_SC_REALTIME_SIGNALS", 20 },
#endif
#ifndef _SC_REGEXP
        { "_SC_REGEXP", 10 },
#endif
#ifndef _SC_REGEX_VERSION
        { "_SC_REGEX_VERSION", 17 },
#endif
#ifndef _SC_RE_DUP_MAX
        { "_SC_RE_DUP_MAX", 14 },
#endif
#ifndef _SC_RTSIG_MAX
        { "_SC_RTSIG_MAX", 13 },
#endif
#ifndef _SC_SAVED_IDS
        { "_SC_SAVED_IDS", 13 },
#endif
#ifndef _SC_SCHAR_MAX
        { "_SC_SCHAR_MAX", 13 },
#endif
#ifndef _SC_SCHAR_MIN
        { "_SC_SCHAR_MIN", 13 },
#endif
#ifndef _SC_SELECT
        { "_SC_SELECT", 10 },
#endif
#ifndef _SC_SEMAPHORES
        { "_SC_SEMAPHORES", 14 },
#endif
#ifndef _SC_SEM_NSEMS_MAX
        { "_SC_SEM_NSEMS_MAX", 17 },
#endif
#ifndef _SC_SEM_VALUE_MAX
        { "_SC_SEM_VALUE_MAX", 17 },
#endif
#ifndef _SC_SHARED_MEMORY_OBJECTS
        { "_SC_SHARED_MEMORY_OBJECTS", 25 },
#endif
#ifndef _SC_SHELL
        { "_SC_SHELL", 9 },
#endif
#ifndef _SC_SHRT_MAX
        { "_SC_SHRT_MAX", 12 },
#endif
#ifndef _SC_SHRT_MIN
        { "_SC_SHRT_MIN", 12 },
#endif
#ifndef _SC_SIGNALS
        { "_SC_SIGNALS", 11 },
#endif
#ifndef _SC_SIGQUEUE_MAX
        { "_SC_SIGQUEUE_MAX", 16 },
#endif
#ifndef _SC_SIGSTKSZ
        { "_SC_SIGSTKSZ", 12 },
#endif
#ifndef _SC_SINGLE_PROCESS
        { "_SC_SINGLE_PROCESS", 18 },
#endif
#ifndef _SC_SPAWN
        { "_SC_SPAWN", 9 },
#endif
#ifndef _SC_SPIN_LOCKS
        { "_SC_SPIN_LOCKS", 14 },
#endif
#ifndef _SC_SPORADIC_SERVER
        { "_SC_SPORADIC_SERVER", 19 },
#endif
#ifndef _SC_SSIZE_MAX
        { "_SC_SSIZE_MAX", 13 },
#endif
#ifndef _SC_SS_REPL_MAX
        { "_SC_SS_REPL_MAX", 15 },
#endif
#ifndef _SC_STREAMS
        { "_SC_STREAMS", 11 },
#endif
#ifndef _SC_STREAM_MAX
        { "_SC_STREAM_MAX", 14 },
#endif
#ifndef _SC_SYMLOOP_MAX
        { "_SC_SYMLOOP_MAX", 15 },
#endif
#ifndef _SC_SYNCHRONIZED_IO
        { "_SC_SYNCHRONIZED_IO", 19 },
#endif
#ifndef _SC_SYSTEM_DATABASE
        { "_SC_SYSTEM_DATABASE", 19 },
#endif
#ifndef _SC_SYSTEM_DATABASE_R
        { "_SC_SYSTEM_DATABASE_R", 21 },
#endif
#ifndef _SC_THREADS
        { "_SC_THREADS", 11 },
#endif
#ifndef _SC_THREAD_ATTR_STACKADDR
        { "_SC_THREAD_ATTR_STACKADDR", 25 },
#endif
#ifndef _SC_THREAD_ATTR_STACKSIZE
        { "_SC_THREAD_ATTR_STACKSIZE", 25 },
#endif
#ifndef _SC_THREAD_CPUTIME
        { "_SC_THREAD_CPUTIME", 18 },
#endif
#ifndef _SC_THREAD_DESTRUCTOR_ITERATIONS
        { "_SC_THREAD_DESTRUCTOR_ITERATIONS", 32 },
#endif
#ifndef _SC_THREAD_KEYS_MAX
        { "_SC_THREAD_KEYS_MAX", 19 },
#endif
#ifndef _SC_THREAD_PRIORITY_SCHEDULING
        { "_SC_THREAD_PRIORITY_SCHEDULING", 30 },
#endif
#ifndef _SC_THREAD_PRIO_INHERIT
        { "_SC_THREAD_PRIO_INHERIT", 23 },
#endif
#ifndef _SC_THREAD_PRIO_PROTECT
        { "_SC_THREAD_PRIO_PROTECT", 23 },
#endif
#ifndef _SC_THREAD_PROCESS_SHARED
        { "_SC_THREAD_PROCESS_SHARED", 25 },
#endif
#ifndef _SC_THREAD_ROBUST_PRIO_INHERIT
        { "_SC_THREAD_ROBUST_PRIO_INHERIT", 30 },
#endif
#ifndef _SC_THREAD_ROBUST_PRIO_PROTECT
        { "_SC_THREAD_ROBUST_PRIO_PROTECT", 30 },
#endif
#ifndef _SC_THREAD_SAFE_FUNCTIONS
        { "_SC_THREAD_SAFE_FUNCTIONS", 25 },
#endif
#ifndef _SC_THREAD_SPORADIC_SERVER
        { "_SC_THREAD_SPORADIC_SERVER", 26 },
#endif
#ifndef _SC_THREAD_STACK_MIN
        { "_SC_THREAD_STACK_MIN", 20 },
#endif
#ifndef _SC_THREAD_THREADS_MAX
        { "_SC_THREAD_THREADS_MAX", 22 },
#endif
#ifndef _SC_TIMEOUTS
        { "_SC_TIMEOUTS", 12 },
#endif
#ifndef _SC_TIMERS
        { "_SC_TIMERS", 10 },
#endif
#ifndef _SC_TIMER_MAX
        { "_SC_TIMER_MAX", 13 },
#endif
#ifndef _SC_TRACE
        { "_SC_TRACE", 9 },
#endif
#ifndef _SC_TRACE_EVENT_FILTER
        { "_SC_TRACE_EVENT_FILTER", 22 },
#endif
#ifndef _SC_TRACE_EVENT_NAME_MAX
        { "_SC_TRACE_EVENT_NAME_MAX", 24 },
#endif
#ifndef _SC_TRACE_INHERIT
        { "_SC_TRACE_INHERIT", 17 },
#endif
#ifndef _SC_TRACE_LOG
        { "_SC_TRACE_LOG", 13 },
#endif
#ifndef _SC_TRACE_NAME_MAX
        { "_SC_TRACE_NAME_MAX", 18 },
#endif
#ifndef _SC_TRACE_SYS_MAX
        { "_SC_TRACE_SYS_MAX", 17 },
#endif
#ifndef _SC_TRACE_USER_EVENT_MAX
        { "_SC_TRACE_USER_EVENT_MAX", 24 },
#endif
#ifndef _SC_TTY_NAME_MAX
        { "_SC_TTY_NAME_MAX", 16 },
#endif
#ifndef _SC_TYPED_MEMORY_OBJECTS
        { "_SC_TYPED_MEMORY_OBJECTS", 24 },
#endif
#ifndef _SC_TZNAME_MAX
        { "_SC_TZNAME_MAX", 14 },
#endif
#ifndef _SC_T_IOV_MAX
        { "_SC_T_IOV_MAX", 13 },
#endif
#ifndef _SC_UCHAR_MAX
        { "_SC_UCHAR_MAX", 13 },
#endif
#ifndef _SC_UINT_MAX
        { "_SC_UINT_MAX", 12 },
#endif
#ifndef _SC_UIO_MAXIOV
        { "_SC_UIO_MAXIOV", 14 },
#endif
#ifndef _SC_ULONG_MAX
        { "_SC_ULONG_MAX", 13 },
#endif
#ifndef _SC_USER_GROUPS
        { "_SC_USER_GROUPS", 15 },
#endif
#ifndef _SC_USER_GROUPS_R
        { "_SC_USER_GROUPS_R", 17 },
#endif
#ifndef _SC_USHRT_MAX
        { "_SC_USHRT_MAX", 13 },
#endif
#ifndef _SC_V6_ILP32_OFF32
        { "_SC_V6_ILP32_OFF32", 18 },
#endif
#ifndef _SC_V6_ILP32_OFFBIG
        { "_SC_V6_ILP32_OFFBIG", 19 },
#endif
#ifndef _SC_V6_LP64_OFF64
        { "_SC_V6_LP64_OFF64", 17 },
#endif
#ifndef _SC_V6_LPBIG_OFFBIG
        { "_SC_V6_LPBIG_OFFBIG", 19 },
#endif
#ifndef _SC_V7_ILP32_OFF32
        { "_SC_V7_ILP32_OFF32", 18 },
#endif
#ifndef _SC_V7_ILP32_OFFBIG
        { "_SC_V7_ILP32_OFFBIG", 19 },
#endif
#ifndef _SC_V7_LP64_OFF64
        { "_SC_V7_LP64_OFF64", 17 },
#endif
#ifndef _SC_V7_LPBIG_OFFBIG
        { "_SC_V7_LPBIG_OFFBIG", 19 },
#endif
#ifndef _SC_VERSION
        { "_SC_VERSION", 11 },
#endif
#ifndef _SC_WORD_BIT
        { "_SC_WORD_BIT", 12 },
#endif
#ifndef _SC_XBS5_ILP32_OFF32
        { "_SC_XBS5_ILP32_OFF32", 20 },
#endif
#ifndef _SC_XBS5_ILP32_OFFBIG
        { "_SC_XBS5_ILP32_OFFBIG", 21 },
#endif
#ifndef _SC_XBS5_LP64_OFF64
        { "_SC_XBS5_LP64_OFF64", 19 },
#endif
#ifndef _SC_XBS5_LPBIG_OFFBIG
        { "_SC_XBS5_LPBIG_OFFBIG", 21 },
#endif
#ifndef _SC_XOPEN_CRYPT
        { "_SC_XOPEN_CRYPT", 15 },
#endif
#ifndef _SC_XOPEN_ENH_I18N
        { "_SC_XOPEN_ENH_I18N", 18 },
#endif
#ifndef _SC_XOPEN_LEGACY
        { "_SC_XOPEN_LEGACY", 16 },
#endif
#ifndef _SC_XOPEN_REALTIME
        { "_SC_XOPEN_REALTIME", 18 },
#endif
#ifndef _SC_XOPEN_REALTIME_THREADS
        { "_SC_XOPEN_REALTIME_THREADS", 26 },
#endif
#ifndef _SC_XOPEN_SHM
        { "_SC_XOPEN_SHM", 13 },
#endif
#ifndef _SC_XOPEN_STREAMS
        { "_SC_XOPEN_STREAMS", 17 },
#endif
#ifndef _SC_XOPEN_UNIX
        { "_SC_XOPEN_UNIX", 14 },
#endif
#ifndef _SC_XOPEN_VERSION
        { "_SC_XOPEN_VERSION", 17 },
#endif
#ifndef _SC_XOPEN_XCU_VERSION
        { "_SC_XOPEN_XCU_VERSION", 21 },
#endif
#ifndef _SC_XOPEN_XPG2
        { "_SC_XOPEN_XPG2", 14 },
#endif
#ifndef _SC_XOPEN_XPG3
        { "_SC_XOPEN_XPG3", 14 },
#endif
#ifndef _SC_XOPEN_XPG4
        { "_SC_XOPEN_XPG4", 14 },
#endif
        { NULL, 0 } };
struct iv_s {const char *name; I32 namelen; IV value;};
